dosertools package — dosertools 2022 documentation

# dosertools package

## Subpackages

- dosertools.data_processing package
  - Submodules
  - dosertools.data_processing.array module
  - dosertools.data_processing.csv module
  - dosertools.data_processing.extension module
  - dosertools.data_processing.figures module
  - dosertools.data_processing.fitting module
  - dosertools.data_processing.integration module
  - Module contents
- dosertools.file_handling package
  - Submodules
  - dosertools.file_handling.folder module
  - dosertools.file_handling.tags module
  - Module contents
- dosertools.image_processing package
  - Submodules
  - dosertools.image_processing.binary module
  - dosertools.image_processing.tiff_handling module
  - Module contents

## Module contents